==> haskell-wl-pprint-terminfo-3.7.1.4-554.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-terminfo
version:              3.7.1.4
visibility:           public
id:                   wl-pprint-terminfo-3.7.1.4-5BLMXvzmQBH4cg1weK4hep
key:                  wl-pprint-terminfo-3.7.1.4-5BLMXvzmQBH4cg1weK4hep
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-terminfo/
synopsis:             A color pretty printer with terminfo support
description:          A color pretty printer with terminfo support
category:             Control, Monads, Text
abi:                  e45c9136f91ffa890c5fb39644779555
exposed:              True
exposed-modules:      System.Console.Terminfo.PrettyPrint
hidden-modules:       System.Console.Terminfo.PrettyPrint.Curses
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-terminfo
hs-libraries:         HSwl-pprint-terminfo-3.7.1.4-5BLMXvzmQBH4cg1weK4hep
extra-libraries:      ncursesw
includes:             cursed.h
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 terminfo-0.4.1.6
    text-2.0.2 transformers-0.6.1.0
    wl-pprint-extras-3.5.0.5-EbiadCa06z64cP8akzaS3L

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-terminfo-3.7.1.4-555-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-terminfo
version:              3.7.1.4
visibility:           public
id:                   wl-pprint-terminfo-3.7.1.4-2HV0Z1HAsCu7lLyPJelxog
key:                  wl-pprint-terminfo-3.7.1.4-2HV0Z1HAsCu7lLyPJelxog
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-terminfo/
synopsis:             A color pretty printer with terminfo support
description:          A color pretty printer with terminfo support
category:             Control, Monads, Text
abi:                  b60a1a11606d1f11cb081880d5217c69
exposed:              True
exposed-modules:      System.Console.Terminfo.PrettyPrint
hidden-modules:       System.Console.Terminfo.PrettyPrint.Curses
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-terminfo
hs-libraries:         HSwl-pprint-terminfo-3.7.1.4-2HV0Z1HAsCu7lLyPJelxog
extra-libraries:      ncursesw
includes:             cursed.h
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 terminfo-0.4.1.6
    text-2.0.2 transformers-0.6.1.0
    wl-pprint-extras-3.5.0.5-JkvCysZQ9OwEvBJ08U4yfL

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
